@@ -1,11 +1,11 @@
 package Reddit::Client;
 
-our $VERSION = '1.098';  
-# 1.098:
-# print_response - for debugging, will print Reddit's actual response
-# submit_link and submit_text can now accept 'sub' as well as 'subreddit'
-# and get_subreddit_comments too
-# remove function in main, Link, and Comment
+our $VERSION = '1.099';  
+# 1.099:
+#  -updated get_user and list_subreddits to use set_listing_defaults
+#  -get_user can now accept the 'about' view
+#  -added 'about' user contant
+#  -added "delete" method to Link, which documentation already said was there
 
 $VERSION = eval $VERSION;
 
@@ -71,6 +71,7 @@ use constant USER_UPVOTED            => 'upvoted';
 use constant USER_DOWNVOTED          => 'downvoted';
 use constant USER_HIDDEN             => 'hidden';
 use constant USER_SAVED              => 'saved';
+use constant USER_ABOUT              => 'about';
 
 use constant API_ME                  => 0;
 use constant API_INFO                => 1;
@@ -388,16 +389,10 @@ sub me {
 }
 sub list_subreddits {
     	my ($self, %param) = @_;
-
 	my $type = $param{view} || SUBREDDITS_HOME;
-    	my $query  = {};
-        $query->{before} = $param{before} if $param{before};
-        $query->{after}  = $param{after}  if $param{after};
-	if (exists $param{limit}) { $query->{limit} = $param{limit} || 500; }
-	else 			  { $query->{limit} = DEFAULT_LIMIT;	    }
+	$type = '' if lc $type eq 'home';
 
-	DEBUG('List subreddits [%s]', $type);
-	defined $type || croak 'Expected $type"';
+	my $query = $self->set_listing_defaults(%param);
 
 	my $api = $type eq SUBREDDITS_MOD || $type eq SUBREDDITS_CONTRIB || $type eq SUBREDDITS_MINE ? API_MY_SUBREDDITS : API_SUBREDDITS; 
 
@@ -696,11 +691,7 @@ sub get_user {
 	my $view	= $param{view} || 'overview';
 	my $user	= $param{user} || croak "expected 'user'";
 
-    	my $query  = {};
-        $query->{before} = $param{before} if $param{before};
-        $query->{after}  = $param{after}  if $param{after};
-	if (exists $param{limit}) { $query->{limit} = $param{limit} || 500; }
-	else 			  { $query->{limit} = DEFAULT_LIMIT;	    }
+	my $query = $self->set_listing_defaults(%param);
 
     	my $args = [$user, $view];
 
@@ -710,6 +701,10 @@ sub get_user {
 		data     => $query,
 	);
 
+	if ($view eq 'about') {
+		#return $result->{data};
+		return Reddit::Client::Account->new($self, $result->{data});
+	}
 	return [
 		map {
 
@@ -721,6 +716,8 @@ sub get_user {
 		@{$result->{data}{children}} 
 	];
 }
+# Remember that this will return a new hash and any key not from here will be
+# wuped out
 sub set_listing_defaults {
     	my ($self, %param) = @_;
 	my $query = {};
